# Gimpformats Index

> Auto-generated documentation index.

A full list of `Gimpformats` project modules.

- [Gimpformats](gimpformats/index.md#gimpformats)
    - [Binaryiotools](gimpformats/binaryiotools.md#binaryiotools)
    - [Gimpchannel](gimpformats/GimpChannel.md#gimpchannel)
    - [Gimpgbrbrush](gimpformats/GimpGbrBrush.md#gimpgbrbrush)
    - [Gimpggrgradient](gimpformats/GimpGgrGradient.md#gimpggrgradient)
    - [Gimpgihbrushset](gimpformats/GimpGihBrushSet.md#gimpgihbrushset)
    - [Gimpgpbbrush](gimpformats/GimpGpbBrush.md#gimpgpbbrush)
    - [Gimpgplpalette](gimpformats/GimpGplPalette.md#gimpgplpalette)
    - [Gimpgtptoolpreset](gimpformats/GimpGtpToolPreset.md#gimpgtptoolpreset)
    - [Gimpimagehierarchy](gimpformats/GimpImageHierarchy.md#gimpimagehierarchy)
    - [Gimpimagelevel](gimpformats/GimpImageLevel.md#gimpimagelevel)
    - [Gimpiobase](gimpformats/GimpIOBase.md#gimpiobase)
    - [Gimplayer](gimpformats/GimpLayer.md#gimplayer)
    - [Gimpparasites](gimpformats/GimpParasites.md#gimpparasites)
    - [Gimppatpattern](gimpformats/GimpPatPattern.md#gimppatpattern)
    - [Gimpprecision](gimpformats/GimpPrecision.md#gimpprecision)
    - [Gimpvbrbrush](gimpformats/GimpVbrBrush.md#gimpvbrbrush)
    - [Gimpvectors](gimpformats/GimpVectors.md#gimpvectors)
    - [Gimpxcfdocument](gimpformats/gimpXcfDocument.md#gimpxcfdocument)
    - [Native Convert](gimpformats/native_convert.md#native-convert)
    - [Utils](gimpformats/utils.md#utils)
- [Test Informal](test_informal/index.md#test-informal)
    - [Test Gimp Document](test_informal/test_gimp_document.md#test-gimp-document)
    - [Test Native Convert](test_informal/test_native_convert.md#test-native-convert)
